@@ -1,8 +1,9 @@
 from discordmenu.embed.components import EmbedFooter
 from discordmenu.embed.view_state import ViewState
 from discordmenu.intra_message_state import IntraMessageState
+from tsutils.query_settings.query_settings import QuerySettings
 
-from tsutils.tsubaki.links import CLOUDFRONT_URL
+from tsutils.tsubaki.links import CLOUDFRONT_URL, MonsterImage
 
 TSUBAKI_FLOWER_ICON_URL = CLOUDFRONT_URL + '/tsubaki/tsubakiflower.png'
 
@@ -11,7 +12,14 @@ def embed_footer():
     return EmbedFooter('Requester may click the reactions below to switch tabs')
 
 
-def embed_footer_with_state(state: ViewState, *, image_url=None, text=None):
+def embed_footer_with_state(state: ViewState, *, image_url=None, text=None, qs: QuerySettings = None):
+    if image_url is None:
+        # don't overwrite specified important images e.g. in link mirror
+        if qs is not None and qs.favcard is not None:
+            if qs.favcard != 0:
+                # use 0 as the setting for "I want to go back to the flower icon" after having
+                # previously selected a favcard
+                image_url = MonsterImage.icon(qs.favcard)
     if image_url is None:
         image_url = TSUBAKI_FLOWER_ICON_URL
     if text is None:
